@@ -82,7 +82,7 @@ class XYTiler(object):
             j_offset = 0
             for tj in range(tile_j1, tile_j2+1):
                 j_beg = j1 if tj == tile_j1 else 0
-                j_end = j2 + 1 if tj == tile_j2 else self.ny
+                j_end = j2 + 1 if (tj == tile_j2 and j2 < self.ny) else self.ny
                 j_size = j_end - j_beg
                 j_beg_dict[tj] = j_beg
                 j_end_dict[tj] = j_end
@@ -93,7 +93,7 @@ class XYTiler(object):
             i_offset = 0
             for ti in range(tile_i1, tile_i2+1):
                 i_beg = i1 if ti == tile_i1 else 0
-                i_end = i2 + 1 if ti == tile_i2 else self.nx
+                i_end = i2 + 1 if (ti == tile_i2 and i2 < self.nx) else self.nx
                 i_size = i_end - i_beg
                 i_beg_dict[ti] = i_beg
                 i_end_dict[ti] = i_end
